==> chromium-browser_34.0.1847.116.orig.tar.xz: chromium-34.0.1847.116/chrome/android/java/src/org/chromium/chrome/browser/infobar/TranslateInfoBarDelegate.java <==
// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.infobar;

import org.chromium.base.CalledByNative;

/**
 * Translate JNI methods
 */
public class TranslateInfoBarDelegate {
    private TranslateInfoBar mInfoBar;

    private TranslateInfoBarDelegate() {}

    @CalledByNative
    public static TranslateInfoBarDelegate create() {
        return new TranslateInfoBarDelegate();
    }

    @CalledByNative
    boolean changeTranslateInfoBarTypeAndPointer(
            long newNativeInfoBar, int translateBarType) {
        mInfoBar.changeInfoBarTypeAndNativePointer(translateBarType, newNativeInfoBar);
        return true;
    }

    @CalledByNative
    InfoBar showTranslateInfoBar(
            long nativeInfoBar, int translateBarType,
            int sourceLanguageIndex, int targetLanguageIndex, boolean autoTranslatePair,
            boolean showNeverInfobar, String[] languages) {
        mInfoBar = new TranslateInfoBar(nativeInfoBar, this, translateBarType,
                sourceLanguageIndex, targetLanguageIndex, autoTranslatePair, showNeverInfobar,
                languages);
        return mInfoBar;
    }

    public void applyTranslateOptions(long nativeTranslateInfoBar,
            int sourceLanguageIndex, int targetLanguageIndex, boolean alwaysTranslate,
            boolean neverTranslateLanguage, boolean neverTranslateSite) {
        nativeApplyTranslateOptions(nativeTranslateInfoBar, sourceLanguageIndex,
                targetLanguageIndex, alwaysTranslate, neverTranslateLanguage, neverTranslateSite);
    }

    private native void nativeApplyTranslateOptions(long nativeTranslateInfoBar,
            int sourceLanguageIndex, int targetLanguageIndex, boolean alwaysTranslate,
            boolean neverTranslateLanguage, boolean neverTranslateSite);
}

==> chromium-browser_37.0.2062.120.orig.tar.xz: chromium-37.0.2062.120/chrome/android/java/src/org/chromium/chrome/browser/infobar/TranslateInfoBarDelegate.java <==
// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.infobar;

import org.chromium.base.CalledByNative;

/**
 * Translate JNI methods
 */
public class TranslateInfoBarDelegate {
    private TranslateInfoBar mInfoBar;

    private TranslateInfoBarDelegate() {}

    @CalledByNative
    public static TranslateInfoBarDelegate create() {
        return new TranslateInfoBarDelegate();
    }

    @CalledByNative
    boolean changeTranslateInfoBarTypeAndPointer(
            long newNativeInfoBar, int translateBarType) {
        mInfoBar.changeInfoBarTypeAndNativePointer(
                translateBarType, newNativeInfoBar);
        return true;
    }

    @CalledByNative
    InfoBar showTranslateInfoBar(
            long nativeInfoBar, int translateBarType,
            int sourceLanguageIndex, int targetLanguageIndex, boolean autoTranslatePair,
            boolean showNeverInfobar, boolean triggeredFromMenu,
            String[] languages) {
        mInfoBar = new TranslateInfoBar(nativeInfoBar, this, translateBarType,
                sourceLanguageIndex, targetLanguageIndex, autoTranslatePair, showNeverInfobar,
                triggeredFromMenu, languages);
        return mInfoBar;
    }

    public void applyTranslateOptions(long nativeTranslateInfoBar,
            int sourceLanguageIndex, int targetLanguageIndex, boolean alwaysTranslate,
            boolean neverTranslateLanguage, boolean neverTranslateSite) {
        nativeApplyTranslateOptions(nativeTranslateInfoBar, sourceLanguageIndex,
                targetLanguageIndex, alwaysTranslate, neverTranslateLanguage, neverTranslateSite);
    }

    private native void nativeApplyTranslateOptions(long nativeTranslateInfoBar,
            int sourceLanguageIndex, int targetLanguageIndex, boolean alwaysTranslate,
            boolean neverTranslateLanguage, boolean neverTranslateSite);
}
